aboutsummaryrefslogtreecommitdiff
path: root/src/app
diff options
context:
space:
mode:
author0neGal <mail@0negal.com>2024-01-12 00:19:20 +0100
committer0neGal <mail@0negal.com>2024-01-12 00:19:20 +0100
commitca466e2b7494d51231df2dd81f69e6abd56fe2b1 (patch)
tree81124439915348cd2c5e6040bbc06c964e39fbc0 /src/app
parent05ea0cc58c0e6d6ebd1fc7cd4a135cefe2ec7dfc (diff)
downloadViper-ca466e2b7494d51231df2dd81f69e6abd56fe2b1.tar.gz
Viper-ca466e2b7494d51231df2dd81f69e6abd56fe2b1.zip
deprecate ns_startup_args.txt
Ideally this has no side effects, however, I've not actually tested if the launching does properly use the launch arguments, due to not having a Windows device on hand. This will be tested later... We still attempt to load launch arguments from `ns_startup_args.txt` if none is set in the settings. However, this may be removed in the future.
Diffstat (limited to 'src/app')
-rw-r--r--src/app/main.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/app/main.js b/src/app/main.js
index 3ee95ce..f5fe19f 100644
--- a/src/app/main.js
+++ b/src/app/main.js
@@ -75,9 +75,9 @@ if (fs.existsSync("viper.json")) {
// filepath to Northstar's startup args file
let args = path.join(settings.gamepath, "ns_startup_args.txt");
- // check file exists
- if (fs.existsSync(args)) {
- // load file into `settings`
+ // check file exists, and that no `nsargs` setting was set
+ if (! settings.nsargs && fs.existsSync(args)) {
+ // load arguments from file into `settings`
settings.nsargs = fs.readFileSync(args, "utf8");
}
}